@@ -308,7 +308,7 @@ def test_tues_run_with_stderr_stdout(capsys, user):
     run = _tues.run("localhost", "echo -n out ; echo -n err >&2", stderr=_tues.STDOUT, text=True, user=user, check=True)
     captured = capsys.readouterr()
     assert run.stderr is None
-    assert captured.out == "outerr"
+    assert captured.out in ("outerr", "errout")
 
 
 @user_param
@@ -458,6 +458,7 @@ def test_output_dir_strategy_ignore(tmp_path):
     _tues.run("localhost", "id", output_dir=str(o), output_dir_strategy=_tues.DIR_IGNORE)
     assert (o / "localhost.log").exists() and (o / "foo.log").exists()
 
+
 def test_output_dir_strategy_wipe(tmp_path):
     o = (tmp_path / "output")
     o.mkdir()
